@@ -5,9 +5,10 @@ use warnings;
 use base qw( Exporter );
 
 our @EXPORT = qw( scalar_to_buffer buffer_to_scalar );
+our @EXPORT_OK = qw ( scalar_to_pointer );
 
 # ABSTRACT: Convert scalars to C buffers
-our $VERSION = '0.56'; # VERSION
+our $VERSION = '0.83'; # VERSION
 
 
 use constant _incantation => 
@@ -21,6 +22,12 @@ sub scalar_to_buffer ($)
   (unpack(_incantation, pack 'P', $_[0]), do { use bytes; length $_[0] });
 }
 
+
+sub scalar_to_pointer ($)
+{
+  unpack(_incantation, pack 'P', $_[0]);
+}
+
       
 sub buffer_to_scalar ($$)
 {
@@ -41,7 +48,7 @@ FFI::Platypus::Buffer - Convert scalars to C buffers
 
 =head1 VERSION
 
-version 0.56
+version 0.83
 
 =head1 SYNOPSIS
 
@@ -110,6 +117,15 @@ copying the buffer instead.  For example:
  # Since you allocated the copy, you are responsible for free'ing it.
  free($ptr_copy);
 
+=head2 scalar_to_pointer
+
+ my $pointer = scalar_to_pointer $scalar;
+
+Get the pointer to the scalar.  (Similar to C<scalar_to_buffer> above, but
+the size of the scalar is not computed or returned).
+
+Not exported by default, but may be exported on request.
+
 =head2 buffer_to_scalar
 
  my $scalar = buffer_to_scalar $pointer, $size;
@@ -159,7 +175,7 @@ Ilya Pavlov (Ilya33)
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015,2016,2017,2018 by Graham Ollis.
+This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
