@@ -10,7 +10,7 @@ use constant 1.32 ();
 our @EXPORT = qw( record_layout );
 
 # ABSTRACT: FFI support for structured records data
-our $VERSION = '0.47'; # VERSION
+our $VERSION = '0.83'; # VERSION
 
 
 sub record_layout
@@ -53,8 +53,7 @@ sub record_layout
     {
 
       if($meta->{type} eq 'string'
-      && $meta->{access} eq 'rw'
-      && $meta->{fixed_size} == 0)
+      && $meta->{access} eq 'rw')
       {
         push @destroy, eval '# line '. __LINE__ . ' "' . __FILE__ . qq("\n) .qq{
           sub {
@@ -64,13 +63,13 @@ sub record_layout
         die $@ if $@;
       }
 
-      $name = join '::', $caller, $name;
-      my $error_str =_accessor
-        $name,
+      my $full_name = join '::', $caller, $name;
+      my $error_str = _accessor
+        $full_name,
         "$filename:$line",
         $ffi->_type_lookup($type),
         $offset;
-      croak($error_str) if $error_str;
+      croak("$error_str ($type $name)") if $error_str;
     };
     
     $offset += $size;
@@ -81,6 +80,7 @@ sub record_layout
   no strict 'refs';
   constant->import("${caller}::_ffi_record_size", $size);
   constant->import("${caller}::_ffi_record_align", $record_align);
+  *{join '::', $caller, '_ffi_record_ro'} = \&_ffi_record_ro;
   *{join '::', $caller, 'new'} = sub {
     my $class = shift;
     my $args = ref($_[0]) ? [%{$_[0]}] : \@_;
@@ -104,6 +104,7 @@ sub record_layout
   if(@destroy)
   {
     $destroy_sub = sub {
+      return if _ffi_record_ro($_[0]);
       $_->($_[0]) for @destroy;
     };
   }
@@ -128,7 +129,7 @@ FFI::Platypus::Record - FFI support for structured records data
 
 =head1 VERSION
 
-version 0.47
+version 0.83
 
 =head1 SYNOPSIS
 
@@ -155,7 +156,7 @@ Perl:
    int       age
    string(3) title
    string_rw name
- );
+ ));
  
  package main;
  
@@ -372,9 +373,15 @@ Vickenty Fesunov (vyf)
 
 Gregor Herrmann (gregoa)
 
+Shlomi Fish (shlomif)
+
+Damyan Ivanov
+
+Ilya Pavlov (Ilya33)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Graham Ollis.
+This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
