@@ -7,7 +7,7 @@ use Scalar::Util qw( readonly );
 use Config ();
 
 # ABSTRACT: Convert a pointer to a string and back
-our $VERSION = '0.47'; # VERSION
+our $VERSION = '0.83'; # VERSION
 
 
 use constant _incantation =>
@@ -76,7 +76,7 @@ FFI::Platypus::Type::StringPointer - Convert a pointer to a string and back
 
 =head1 VERSION
 
-version 0.47
+version 0.83
 
 =head1 SYNOPSIS
 
@@ -113,6 +113,10 @@ In your Platypus::FFI code:
 
 =head1 DESCRIPTION
 
+B<NOTE>: As of version 0.61, this custom type is now deprecated since
+pointers to strings are supported in the L<FFI::Platypus> directly
+without custom types.
+
 This module provides a L<FFI::Platypus> custom type for pointers to
 strings.
 
@@ -150,9 +154,15 @@ Vickenty Fesunov (vyf)
 
 Gregor Herrmann (gregoa)
 
+Shlomi Fish (shlomif)
+
+Damyan Ivanov
+
+Ilya Pavlov (Ilya33)
+
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by Graham Ollis.
+This software is copyright (c) 2015,2016,2017,2018,2019 by Graham Ollis.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
